"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = void 0;
const config_1 = require("./config");
const log_1 = require("./log");
const process_1 = require("./process");
const run = async (exitCode) => {
    const config = await (0, config_1.readConfig)();
    const packages = Object.entries(config);
    if (packages.length === 0) {
        (0, log_1.log)('error', 'No packages were modified');
        process.exitCode = exitCode;
        process.exit();
    }
    await Promise.all(packages.map(([pkg, options]) => (0, process_1.processPackage)(pkg, options))).catch((err) => (0, log_1.log)('error', JSON.stringify(err, null, 2)));
    (0, log_1.log)('info', `Typed ${packages.length} packages. (${packages.map((p) => p[0]).join(', ')})`);
};
exports.run = run;
//# sourceMappingURL=index.js.map